@@ -12,13 +12,12 @@
 import React from 'react'
 import msgs from '../../../../nls/platform.properties'
 import { HCMChannelList, HCMSecretsList } from '../../../../lib/client/queries'
+import apolloClient from '../../../../lib/client/apollo-client'
 import { RESOURCE_TYPES } from '../../../../lib/shared/constants'
 import SharedResourceWarning from '../components/SharedResourceWarning'
 
 import _ from 'lodash'
 
-const GitHub = require('github-api')
-
 const onlineClustersCheckbox = 'online-cluster-only-checkbox'
 const existingRuleCheckbox = 'existingrule-checkbox'
 const localClusterCheckbox = 'local-cluster-checkbox'
@@ -206,9 +205,11 @@ export const updateChannelControls = (
   let control
   // if existing channel, hide user/token controls; show it when using the same channel in the same app
   const type = !existingChannel || usingSameChannel ? 'text' : 'hidden'
-  const setType = (cid, isPasswordField) => {
+  const checkboxType =
+    !existingChannel || usingSameChannel ? 'checkbox' : 'hidden'
+  const setType = (cid, isPasswordField, isCheckbox) => {
     control = groupControlData.find(({ id }) => id === cid)
-    let setCtrlType = type
+    let setCtrlType = isCheckbox ? checkboxType : type
     if (isPasswordField) {
       setCtrlType = type === 'hidden' ? type : 'password'
     }
@@ -222,6 +223,7 @@ export const updateChannelControls = (
   case 'githubURL':
     setType('githubUser')
     setType('githubAccessId', true)
+    setType('gitInsecureSkipVerify', false, true)
     break
   case 'objectstoreURL':
     setType('accessKey')
@@ -230,6 +232,7 @@ export const updateChannelControls = (
   case 'helmURL':
     setType('helmUser')
     setType('helmPassword', true)
+    setType('helmInsecureSkipVerify', false, true)
     break
   }
 
@@ -292,53 +295,31 @@ const retrieveGitDetails = async (
       ({ id }) => id === 'githubAccessId'
     )
 
-    let gitPath = _.get(gitControl, 'active', '')
-    let existingPrivateChannel = false
-
-    if (gitPath.length === 0) {
+    const gitUrl = _.get(gitControl, 'active', '')
+    if (!gitUrl) {
       branchCtrl.active = ''
       branchCtrl.available = []
-    }
-    if (gitPath.length === 0) {
       return
     }
 
-    let github = new GitHub()
-
-    if (
-      _.get(userCtrl, 'active', '').length > 0 &&
-      _.get(tokenCtrl, 'active', '').length > 0
-    ) {
-      //use authentication
-      github = new GitHub({
-        username: userCtrl.active,
-        password: tokenCtrl.active,
-        auth: 'basic'
-      })
-    } else {
-      //check if this is an existing private channel
-      const selectedChannel = _.get(
-        _.get(gitControl, 'availableData', {}),
-        gitPath
-      )
-      if (
-        selectedChannel &&
-        _.get(selectedChannel, 'raw.spec.secretRef.name')
-      ) {
-        //this is a private channel, don't try to retreive the branches
-        existingPrivateChannel = true
-      }
-    }
-
-    //check only github repos; and only new private channels since we don't have the channel secret info for existing channels
-    const gitUrl = new URL(gitPath)
-    if (!(gitUrl.host === 'github.com' && existingPrivateChannel === false)) {
+    //check only github repos
+    const url = new URL(gitUrl)
+    if (url.host !== 'github.com') {
       return
     }
 
-    //get the url path, then remove first / and .git
-    gitPath = gitUrl.pathname.substring(1).replace('.git', '')
-    const repoObj = github.getRepo(gitPath)
+    // Check for existing channel
+    const selectedChannel = _.get(
+      _.get(gitControl, 'availableData', {}),
+      gitUrl
+    )
+    const queryVariables = {
+      gitUrl,
+      namespace: _.get(selectedChannel, 'metadata.namespace', ''),
+      secretRef: _.get(selectedChannel, 'secretRef', ''),
+      user: _.get(userCtrl, 'active'),
+      accessToken: _.get(tokenCtrl, 'active')
+    }
 
     githubPathCtrl.active = ''
     githubPathCtrl.available = []
@@ -346,17 +327,16 @@ const retrieveGitDetails = async (
     if (branchName) {
       //get folders for branch
       setLoadingState(githubPathCtrl, true)
-      await repoObj.getContents(branchName, '', false).then(
+      const pathQueryVariables = {
+        ...queryVariables,
+        branch: branchName
+      }
+      apolloClient.getGitChannelPaths(pathQueryVariables).then(
         result => {
-          if (result.data) {
-            const filteredResult = result.data.filter(
-              item => item.type === 'dir'
-            )
-
-            filteredResult.forEach(folder => {
-              githubPathCtrl.available.push(folder.name)
-            })
-          }
+          const items = _.get(result, 'data.items', []) || []
+          items.forEach(path => {
+            githubPathCtrl.available.push(path)
+          })
           setLoadingState(githubPathCtrl, false)
         },
         () => {
@@ -367,28 +347,25 @@ const retrieveGitDetails = async (
     } else {
       //get branches
       setLoadingState(branchCtrl, true)
-
-      await repoObj.listBranches().then(
-        result => {
+      const onError = () => {
+        branchCtrl.exception = msgs.get('creation.app.loading.branch.error')
+        setLoadingState(branchCtrl, false)
+      }
+      apolloClient.getGitChannelBranches(queryVariables).then(result => {
+        if (_.get(result, 'errors')) {
+          onError()
+        } else {
           branchCtrl.active = ''
           branchCtrl.available = []
 
-          if (result.data) {
-            result.data.forEach(branch => {
-              branchCtrl.available.push(branch.name)
-            })
-          }
+          const items = _.get(result, 'data.items', []) || []
+          items.forEach(branch => {
+            branchCtrl.available.push(branch)
+          })
           delete branchCtrl.exception
           setLoadingState(branchCtrl, false)
-        },
-        () => {
-          //on error
-          branchCtrl.active = ''
-          branchCtrl.available = []
-          branchCtrl.exception = msgs.get('creation.app.loading.branch.error')
-          setLoadingState(branchCtrl, false)
         }
-      )
+      }, onError)
     }
   } catch (err) {
     //return err
@@ -416,7 +393,6 @@ export const setAvailableRules = (control, result) => {
   control.available = []
   control.availableMap = {}
   control.isLoading = false
-  control.active = ''
 
   const error = placementrules ? null : result.error
 
@@ -426,6 +402,11 @@ export const setAvailableRules = (control, result) => {
     if (placementrules.length > 0) {
       control.availableData = _.keyBy(placementrules, 'metadata.name')
       control.available = Object.keys(control.availableData).sort()
+      //remove default placement rule name if this is not on the list of available placements
+      //in that case the name was set by the reverse function on control initialization
+      if (control.active && !control.available.includes(control.active)) {
+        control.active = null
+      }
     } else {
       control.availableData = []
     }
@@ -574,6 +555,8 @@ export const updateNewRuleControlsData = (selectedPR, control) => {
 
     _.set(clusterSelectorControl, 'type', 'custom')
     _.set(clusterSelectorControl, 'active.mode', true)
+
+    clusterSelectorControl.active.clusterLabelsListID = 1
     clusterSelectorControl.active.clusterLabelsList = [
       { id: 0, labelName: '', labelValue: '', validValue: false }
     ]
