@@ -8,13 +8,21 @@
 'use strict'
 
 import React from 'react'
-import ResourceTableModule from './common/ResourceTableModuleFromProps'
 import { RESOURCE_TYPES } from '../../lib/shared/constants'
 import { typedResourcePageList } from './common/ResourcePage'
+import { AcmTablePaginationContextProvider } from '@open-cluster-management/ui-components'
 
-export default typedResourcePageList(
+const TypedResourcePageList = typedResourcePageList(
   RESOURCE_TYPES.QUERY_APPLICATIONS,
   [],
   [],
-  [<ResourceTableModule key="deployments" definitionsKey="deploymentKeys" />]
+  []
 )
+
+const ApplicationsListPage = props => (
+  <AcmTablePaginationContextProvider localStorageKey="application-table-pagination">
+    <TypedResourcePageList {...props} />
+  </AcmTablePaginationContextProvider>
+)
+
+export default ApplicationsListPage
