@@ -10,7 +10,7 @@
 
 import msgs from '../../../../../nls/platform.properties'
 import _ from 'lodash'
-import { getClusterName } from '../../utils/diagram-helpers'
+import { getClusterName } from '../../utils/diagram-helpers-utils'
 
 const clusterLabels = 'cluster.metadata.labels'
 
@@ -566,10 +566,13 @@ const filterClusterNodes = (nodes, activeFilters) => {
 }
 
 export const processResourceStatus = (resourceStatuses, resourceStatus) => {
+  const orangeOrYellow =
+    resourceStatus === 'orange' || resourceStatus === 'yellow'
+
   return (
     (resourceStatuses.has('green') && resourceStatus === 'green') ||
     (resourceStatuses.has('yellow') && resourceStatus === 'yellow') ||
-    (resourceStatuses.has('orange') && resourceStatus === 'orange') ||
+    (resourceStatuses.has('orange') && orangeOrYellow) ||
     (resourceStatuses.has('red') && resourceStatus === 'red')
   )
 }
