@@ -11,7 +11,11 @@
 
 import cytoscape from 'cytoscape'
 import cycola from 'cytoscape-cola'
-import { getWrappedNodeLabel, getHashCode } from '../../utils/diagram-helpers'
+import {
+  getWrappedNodeLabel,
+  getHashCode,
+  computeNodeStatus
+} from '../../utils/diagram-helpers'
 import { layoutEdges, setDraggedLineData } from './linkHelper'
 import { getNodeGroups } from '../defaults/grouping'
 import FilterHelper from './filterHelper'
@@ -40,7 +44,7 @@ export default class LayoutHelper {
     this.destroyed = true
   };
 
-  layout = (nodes, links, hiddenLinks, options, cb) => {
+  layout = (nodes, links, hiddenLinks, options, isFilterOn, cb) => {
     Object.assign(this, options)
 
     // filter by currectly selected filters
@@ -93,7 +97,7 @@ export default class LayoutHelper {
     //identify hubs
     this.markHubs(groups)
 
-    // set the node's description
+    // set the node's description and recompute node status
     nodes.forEach(node => {
       if (node.layout) {
         if (this.getNodeTitle) {
@@ -103,6 +107,7 @@ export default class LayoutHelper {
           node.layout.description = this.getNodeDescription(node)
         }
       }
+      computeNodeStatus(node)
     })
 
     // create cytoscape element collections
@@ -123,7 +128,11 @@ export default class LayoutHelper {
     collections = collections.connected.concat(collections.unconnected)
     this.runCollectionLayouts(collections, () => {
       // after all layouts run, fit the collections neatly in the diagram
-      const layoutInfo = this.layoutCollections(collections, hiddenLinks)
+      const layoutInfo = this.layoutCollections(
+        collections,
+        hiddenLinks,
+        isFilterOn
+      )
 
       // return to TopologyView to create/position the d3 svg shapes
       if (!this.destroyed) {
@@ -895,7 +904,7 @@ export default class LayoutHelper {
     })
   };
 
-  layoutCollections = (collections, hiddenLinks) => {
+  layoutCollections = (collections, hiddenLinks, isFilterOn) => {
     // cache layouts
     const clayouts = []
     collections.forEach(
@@ -1093,8 +1102,8 @@ export default class LayoutHelper {
         layoutBBox.x2 = Math.max(layoutBBox.x2 || nx, nx)
         layoutBBox.y2 = Math.max(layoutBBox.y2 || ny, ny)
 
-        // restore position of any node dragged by user
-        if (layout.dragged) {
+        // restore position of any node dragged by user but not when filtering
+        if (layout.dragged && !isFilterOn) {
           // if node is a member of a new section cancel the drag
           if (layout.section.hashCode === hashCodeC) {
             // else reconstitute drag using the current section x/y
