@@ -12,9 +12,18 @@
 
 import { updateNSControls } from "../../../../../src-web/components/ApplicationCreationPage/controlData/ControlData";
 
-import { updatePlacementControlsForLocal } from "../../../../../src-web/components/ApplicationCreationPage/controlData/ControlDataPlacement";
+import {
+  updatePlacementControlsForLocal,
+  reverseExistingRule,
+  updateDisplayForPlacementControls
+} from "../../../../../src-web/components/ApplicationCreationPage/controlData/ControlDataPlacement";
 
-import { updateGitCredentials } from "../../../../../src-web/components/ApplicationCreationPage/controlData/ControlDataGit";
+import { templateObject, placementControlData } from "./TestData";
+
+import {
+  updateGitCredentials,
+  validateBranch
+} from "../../../../../src-web/components/ApplicationCreationPage/controlData/ControlDataGit";
 
 import {
   setAvailableRules,
@@ -262,6 +271,47 @@ describe("updatePrePostControls", () => {
   });
 });
 
+describe("validateBranch", () => {
+  const validGitBranches = [
+    "master",
+    "release-2.1",
+    "master/resource/abc",
+    "master@abc"
+  ];
+  const invalidGitBranches = [
+    "foo/bar.lock/hello",
+    "master..123",
+    "master.",
+    "master/.abc",
+    "/master",
+    "master/",
+    "master/.lock",
+    "master:12",
+    "abc~",
+    "master:",
+    "abc?a",
+    "abc*a",
+    "abc[a",
+    "master@{",
+    "master.",
+    "abc//efg",
+    "master^",
+    "@"
+  ];
+
+  validGitBranches.forEach(branch => {
+    it("verify valid Git branch", () => {
+      expect(validateBranch(branch)).toEqual(true);
+    });
+  });
+
+  invalidGitBranches.forEach(branch => {
+    it("verify invalid Git branch", () => {
+      expect(validateBranch(branch)).toEqual(false);
+    });
+  });
+});
+
 describe("updateGitCredentials", () => {
   const data = {
     active: "",
@@ -622,7 +672,7 @@ describe("setAvailableRules", () => {
     }
   };
   const result = {
-    active: "",
+    active: null,
     available: ["dev-clusters"],
     availableData: {
       "dev-clusters": { metadata: { name: "dev-clusters", namespace: "aa-ns" } }
@@ -650,7 +700,7 @@ describe("setAvailableRules", () => {
     data: {}
   };
   const result = {
-    active: "",
+    active: true,
     available: [],
     availableData: {},
     availableMap: {},
@@ -678,7 +728,7 @@ describe("setAvailableRules", () => {
     loading: "data loading"
   };
   const result = {
-    active: "",
+    active: true,
     available: [],
     availableData: { data: {}, loading: "loading message" },
     availableMap: {},
@@ -969,10 +1019,127 @@ describe("updatePlacementControls with controls", () => {
   };
   const result = [
     { id: "local-cluster-checkbox", type: "checkbox" },
-    { id: "online-cluster-only-checkbox", type: "hidden" },
+    { id: "online-cluster-only-checkbox", type: "hidden", active: false },
     { id: "clusterSelector", type: "hidden" }
   ];
   it("should return local only", () => {
     expect(updatePlacementControlsForLocal(placementControl)).toEqual(result);
   });
 });
+
+describe("reverseExistingRule with template data", () => {
+  const result = {
+    active: "-placement-1",
+    groupControlData: [
+      {
+        active: "-placement-1",
+        id: "selectedRuleName",
+        type: "hidden"
+      },
+      {
+        available: [],
+        controlId: "existingrule-checkbox",
+        groupControlData: [
+          {
+            id: "local-cluster-checkbox",
+            type: "checkbox"
+          },
+          {
+            id: "placementrulecombo",
+            type: "singleselect"
+          },
+          {
+            id: "online-cluster-only-checkbox",
+            type: "checkbox"
+          },
+          {
+            id: "selectedRuleName",
+            type: "hidden"
+          },
+          {
+            active: {},
+            controlId: "clusterSelector",
+            id: "clusterSelector",
+            type: "hidden"
+          }
+        ],
+        id: "existingrule-checkbox",
+        type: "checkbox"
+      }
+    ],
+    id: "placementrulecombo",
+    type: "singleselect"
+  };
+  it("should return non null", () => {
+    expect(reverseExistingRule(placementControlData, templateObject)).toEqual(
+      result
+    );
+  });
+});
+
+describe("updateDisplayForPlacementControls", () => {
+  const existingRuleCb = placementControlData.groupControlData.find(
+    ({ id }) => id === "existingrule-checkbox"
+  );
+  const result = [
+    {
+      active: "-placement-1",
+      id: "selectedRuleName",
+      type: "hidden"
+    },
+    {
+      available: [],
+      controlId: "existingrule-checkbox",
+      groupControlData: [
+        {
+          active: false,
+          id: "local-cluster-checkbox",
+          type: "checkbox"
+        },
+        {
+          active: "",
+          id: "placementrulecombo",
+          type: "hidden"
+        },
+        {
+          active: false,
+          disabled: false,
+          id: "online-cluster-only-checkbox",
+          type: "checkbox"
+        },
+        {
+          active: "",
+          id: "selectedRuleName",
+          type: "hidden"
+        },
+        {
+          active: {
+            clusterLabelsList: [
+              {
+                id: 0,
+                labelName: "",
+                labelValue: "",
+                validValue: false
+              }
+            ],
+            clusterLabelsListID: 1,
+            mode: true
+          },
+          controlId: "clusterSelector",
+          id: "clusterSelector",
+          type: "custom"
+        }
+      ],
+      id: "existingrule-checkbox",
+      type: "checkbox"
+    }
+  ];
+  it("should return placement rule with selected placement rule combo hidden", () => {
+    expect(
+      updateDisplayForPlacementControls(
+        existingRuleCb,
+        placementControlData.groupControlData
+      )
+    ).toEqual(result);
+  });
+});
