@@ -38,8 +38,7 @@ describe("getNodeDetails no clusters or violation", () => {
         {
           name: "Cluster",
           value: "c1",
-          href:
-            "/multicloud/search?filters={'textsearch':'kind:cluster name:c1'}"
+          href: "/search?filters={'textsearch':'kind:cluster name:c1'}"
         }
       ],
       x: 76.5,
@@ -58,8 +57,16 @@ describe("getNodeDetails no clusters or violation", () => {
 
   const expectedResult = [
     { type: "spacer" },
-    { labelKey: "prop.details.section", type: "label" },
-    { type: "spacer" }
+    { labelKey: "prop.details.section.cluster", type: "label" },
+    { type: "spacer" },
+    { labelValue: "Clusters (0)", type: "label" },
+    {
+      comboboxdata: {
+        clusterID: "member--clusters--c1",
+        clusterList: []
+      },
+      type: "clusterdetailcombobox"
+    }
   ];
   it("should process the node, no clusters or violation", () => {
     expect(getNodeDetails(clusterNode, locale)).toEqual(expectedResult);
@@ -95,10 +102,12 @@ describe("getNodeDetails application node", () => {
     },
     name: "nginx-app-3",
     namespace: "ns-sub-1",
+    __typename: "PlacementRule",
     specs: {
       isDesign: true,
       row: 0,
       raw: {
+        kind: "PlacementRule",
         metadata: {
           namespace: "ns-sub-1"
         }
@@ -111,6 +120,18 @@ describe("getNodeDetails application node", () => {
   };
 
   const expectedResult = [
+    {
+      type: "link",
+      value: {
+        data: {
+          action: "show_resource_yaml",
+          cluster: "local-cluster",
+          editLink:
+            "/resources?cluster=local-cluster&kind=placementrule&name=nginx-app-3&namespace=ns-sub-1"
+        },
+        label: "View Resource YAML"
+      }
+    },
     { type: "spacer" },
     { labelKey: "prop.details.section", type: "label" },
     { type: "spacer" },
@@ -158,7 +179,7 @@ describe("getNodeDetails application node", () => {
         data: {
           action: "open_link",
           targetLink:
-            '/multicloud/search?filters={"textsearch":"kind%3Asubscription%20namespace%3Ans-sub-1%20cluster%3Alocal-cluster"}'
+            '/search?filters={"textsearch":"kind%3Asubscription%20namespace%3Ans-sub-1%20cluster%3Alocal-cluster"}'
         },
         id: "application--nginx-app-3-subscrSearch",
         label: "View all subscriptions in {0} namespace"
@@ -167,7 +188,7 @@ describe("getNodeDetails application node", () => {
   ];
 
   it("should process the node, application node", () => {
-    expect(getNodeDetails(applicationNode, locale)).toEqual(expectedResult);
+    expect(getNodeDetails(applicationNode, locale, {})).toEqual(expectedResult);
   });
 });
 
@@ -232,8 +253,7 @@ describe("getNodeDetails cluster node 1", () => {
         {
           name: "Cluster",
           value: "feng",
-          href:
-            "/multicloud/search?filters={'textsearch':'kind:cluster name:feng'}"
+          href: "/search?filters={'textsearch':'kind:cluster name:feng'}"
         }
       ],
       x: 76.5,
@@ -252,60 +272,37 @@ describe("getNodeDetails cluster node 1", () => {
 
   const expectedResult = [
     { type: "spacer" },
-    { labelKey: "prop.details.section", type: "label" },
+    {
+      labelKey: "prop.details.section.cluster",
+      type: "label"
+    },
     { type: "spacer" },
-    { labelKey: "resource.name", value: undefined },
-    { labelKey: "resource.namespace", value: undefined },
     {
-      indent: true,
-      type: "link",
-      value: {
-        data: { action: "open_link", targetLink: "aaa" },
-        id: "aaa-location",
-        label: "Open cluster console"
-      }
+      labelValue: "Clusters (1)",
+      type: "label"
     },
     {
-      indent: undefined,
-      labelKey: "resource.pods",
-      labelValue: undefined,
-      status: undefined,
-      type: "label",
-      value: []
-    },
-    {
-      indent: undefined,
-      labelKey: "resource.nodes",
-      labelValue: undefined,
-      status: undefined,
-      type: "label",
-      value: []
-    },
-    {
-      indent: undefined,
-      labelKey: "resource.cpu",
-      labelValue: undefined,
-      status: undefined,
-      type: "label",
-      value: "20%"
-    },
-    {
-      indent: undefined,
-      labelKey: "resource.memory",
-      labelValue: undefined,
-      status: undefined,
-      type: "label",
-      value: "25%"
-    },
-    {
-      indent: undefined,
-      labelKey: "resource.created",
-      labelValue: undefined,
-      status: undefined,
-      type: "label",
-      value: "-"
-    },
-    { type: "spacer" }
+      comboboxdata: {
+        clusterID: "member--clusters--feng",
+        clusterList: [
+          {
+            allocatable: {
+              cpu: "8",
+              memory: "24",
+              pods: []
+            },
+            capacity: {
+              cpu: "10",
+              memory: "32",
+              nodes: []
+            },
+            consoleURL: "aaa",
+            consoleip: "api"
+          }
+        ]
+      },
+      type: "clusterdetailcombobox"
+    }
   ];
 
   it("should process the node, cluster node 2", () => {
@@ -394,8 +391,7 @@ describe("getNodeDetails clusters node", () => {
         {
           name: "Cluster",
           value: "feng",
-          href:
-            "/multicloud/search?filters={'textsearch':'kind:cluster name:feng'}"
+          href: "/search?filters={'textsearch':'kind:cluster name:feng'}"
         }
       ],
       x: 76.5,
@@ -413,93 +409,66 @@ describe("getNodeDetails clusters node", () => {
   };
 
   const expectedResult = [
-    { type: "spacer" },
-    { labelKey: "prop.details.section", type: "label" },
     { type: "spacer" },
     {
-      labelKey: "resource.clusters",
-      status: undefined,
-      value: "[braveman,possiblereptile]"
+      labelKey: "prop.details.section.cluster",
+      type: "label"
     },
     { type: "spacer" },
-    { labelKey: "resource.name", value: undefined },
-    { labelKey: "resource.namespace", value: undefined },
     {
-      indent: undefined,
-      labelKey: "resource.nodes",
-      labelValue: undefined,
-      status: undefined,
-      type: "label",
-      value: []
+      labelValue: "Clusters (2)",
+      type: "label"
     },
     {
-      indent: undefined,
-      labelKey: "resource.cpu",
-      labelValue: undefined,
-      status: undefined,
-      type: "label",
-      value: "100%"
-    },
-    {
-      indent: undefined,
-      labelKey: "resource.memory",
-      labelValue: undefined,
-      status: undefined,
-      type: "label",
-      value: "100%"
-    },
-    {
-      indent: undefined,
-      labelKey: "resource.created",
-      labelValue: undefined,
-      status: undefined,
-      type: "label",
-      value: "-"
-    },
-    { type: "spacer" },
-    { labelKey: "resource.name", value: undefined },
-    { labelKey: "resource.namespace", value: undefined },
-    {
-      indent: undefined,
-      labelKey: "resource.pods",
-      labelValue: undefined,
-      status: undefined,
-      type: "label",
-      value: []
-    },
-    {
-      indent: undefined,
-      labelKey: "resource.nodes",
-      labelValue: undefined,
-      status: undefined,
-      type: "label",
-      value: []
-    },
-    {
-      indent: undefined,
-      labelKey: "resource.cpu",
-      labelValue: undefined,
-      status: undefined,
-      type: "label",
-      value: "20%"
-    },
-    {
-      indent: undefined,
-      labelKey: "resource.memory",
-      labelValue: undefined,
-      status: undefined,
-      type: "label",
-      value: "-76700%"
-    },
-    {
-      indent: undefined,
-      labelKey: "resource.created",
-      labelValue: undefined,
-      status: undefined,
-      type: "label",
-      value: "-"
-    },
-    { type: "spacer" }
+      comboboxdata: {
+        clusterID: "member--clusters--braveman",
+        clusterList: [
+          {
+            capacity: {
+              cpu: "10",
+              memory: "32Gi",
+              nodes: [],
+              storage: "500Gi"
+            },
+            metatdata: {
+              labels: {
+                cloud: "AWS",
+                env: "Dev"
+              },
+              name: "braveman",
+              namespace: "default"
+            },
+            usage: {
+              cpu: "8",
+              memory: "24Ti",
+              pods: [],
+              storage: "400Ei"
+            }
+          },
+          {
+            allocatable: {
+              cpu: "8",
+              memory: "24Ti",
+              pods: []
+            },
+            capacity: {
+              cpu: "10",
+              memory: "32Gi",
+              nodes: []
+            },
+            metatdata: {
+              labels: {
+                cloud: "AWS",
+                env: "Dev"
+              },
+              name: "possiblereptile",
+              namespace: "default"
+            }
+          }
+        ]
+      },
+      type: "clusterdetailcombobox"
+    }
   ];
 
   it("should process the clusters node", () => {
@@ -666,12 +635,14 @@ describe("getNodeDetails deployment node", () => {
     topology: null,
     labels: null,
     __typename: "Resource",
+    apiVersion: "v1",
     layout: {
       hasPods: true,
       uid:
         "member--member--deployable--member--clusters--feng--default--mortgage-app-deployable--deployment--mortgage-app-deploy",
       type: "deployment",
       label: "mortgage-app-↵deploy",
+      apiVersion: "v1",
       compactLabel: "mortgage-app-↵deploy",
       nodeStatus: "",
       isDisabled: false,
@@ -682,7 +653,7 @@ describe("getNodeDetails deployment node", () => {
           name: "Deployment",
           value: "mortgage-app-deploy",
           href:
-            "/multicloud/search?filters={'textsearch':'kind:deployment name:mortgage-app-deploy'}"
+            "/search?filters={'textsearch':'kind:deployment name:mortgage-app-deploy'}"
         }
       ],
       x: 151.5,
@@ -712,6 +683,7 @@ describe("getNodeDetails deployment node", () => {
           name: "pod1",
           namespace: "default",
           type: "pod",
+          apiVersion: "v1",
           layout: {
             type: "layout1"
           },
@@ -743,6 +715,14 @@ describe("getNodeDetails deployment node", () => {
       type: "label",
       value: "deployment"
     },
+    {
+      indent: undefined,
+      labelKey: "resource.api.version",
+      labelValue: undefined,
+      status: undefined,
+      type: "label",
+      value: "apps/v1"
+    },
     {
       indent: undefined,
       labelKey: "resource.namespace",
@@ -807,7 +787,8 @@ describe("getNodeDetails deployment node", () => {
         data: {
           action: "show_resource_yaml",
           cluster: "feng",
-          selfLink: "/api/v1/namespaces/default/pods/mortgagedc-deploy-1-q9b5r"
+          editLink:
+            "/resources?cluster=feng&kind=pod&name=mortgagedc-deploy-1-q9b5r&namespace=default"
         },
         label: "View Pod YAML and Logs"
       }
@@ -860,7 +841,8 @@ describe("getNodeDetails deployment node", () => {
         data: {
           action: "show_resource_yaml",
           cluster: "feng",
-          selfLink: "/api/v1/namespaces/default/pods/mortgagedc-deploy-1-q9b5r"
+          editLink:
+            "/resources?cluster=feng&kind=pod&name=mortgagedc-deploy-1-q9b5rr&namespace=default"
         },
         label: "View Pod YAML and Logs"
       }
@@ -893,7 +875,7 @@ describe("getNodeDetails deployment node", () => {
   ];
 
   it("should process the node, deployment node", () => {
-    expect(getNodeDetails(deploymentNode, locale)).toEqual(expectedResult);
+    expect(getNodeDetails(deploymentNode, locale, {})).toEqual(expectedResult);
   });
 });
 
@@ -939,6 +921,14 @@ describe("getNodeDetails helm node", () => {
       type: "label",
       value: "helmrelease"
     },
+    {
+      indent: undefined,
+      labelKey: "resource.api.version",
+      labelValue: undefined,
+      status: undefined,
+      type: "label",
+      value: "app.ibm.com/v1alpha1"
+    },
     {
       indent: undefined,
       labelKey: "resource.namespace",
@@ -980,7 +970,7 @@ describe("getNodeDetails helm node", () => {
   ];
 
   it("should process the node, helm node", () => {
-    expect(getNodeDetails(helmreleaseNode, locale)).toEqual(expectedResult);
+    expect(getNodeDetails(helmreleaseNode, locale, {})).toEqual(expectedResult);
   });
 });
 
@@ -1049,8 +1039,9 @@ describe("getNodeDetails placement rules node with error", () => {
     clusterName: null,
     type: "placements",
     specs: {
+      isDesign: true,
       raw: {
-        apiVersion: "app.ibm.com/v1alpha1",
+        apiVersion: "apps.open-cluster-management.io/v1",
         kind: "PlacementRule",
         metadata: {
           labels: { app: "mortgage-app-mortgage" },
@@ -1069,6 +1060,18 @@ describe("getNodeDetails placement rules node with error", () => {
   };
 
   const expectedResult = [
+    {
+      type: "link",
+      value: {
+        data: {
+          action: "show_resource_yaml",
+          cluster: "local-cluster",
+          editLink:
+            "/resources?apiversion=apps.open-cluster-management.io%2Fv1&cluster=local-cluster&kind=placementrule&name=mortgage-rule"
+        },
+        label: "View Resource YAML"
+      }
+    },
     { type: "spacer" },
     { labelKey: "prop.details.section", type: "label" },
     { type: "spacer" },
@@ -1080,6 +1083,14 @@ describe("getNodeDetails placement rules node with error", () => {
       type: "label",
       value: "placements"
     },
+    {
+      indent: undefined,
+      labelKey: "resource.api.version",
+      labelValue: undefined,
+      status: undefined,
+      type: "label",
+      value: "apps.open-cluster-management.io/v1"
+    },
     {
       indent: undefined,
       labelKey: "resource.namespace",
@@ -1121,7 +1132,7 @@ describe("getNodeDetails placement rules node with error", () => {
     }
   ];
   it("should process the node, placement rules node with error", () => {
-    expect(getNodeDetails(rulesNode, locale)).toEqual(expectedResult);
+    expect(getNodeDetails(rulesNode, locale, {})).toEqual(expectedResult);
   });
 });
 
@@ -1134,8 +1145,9 @@ describe("getNodeDetails placement rules node with success", () => {
     clusterName: null,
     type: "placements",
     specs: {
+      isDesign: true,
       raw: {
-        apiVersion: "app.ibm.com/v1alpha1",
+        apiVersion: "apps.open-cluster-management.io/v1",
         kind: "PlacementRule",
         metadata: {
           labels: { app: "mortgage-app-mortgage" },
@@ -1157,6 +1169,18 @@ describe("getNodeDetails placement rules node with success", () => {
   };
 
   const expectedResult = [
+    {
+      type: "link",
+      value: {
+        data: {
+          action: "show_resource_yaml",
+          cluster: "local-cluster",
+          editLink:
+            "/resources?apiversion=apps.open-cluster-management.io%2Fv1&cluster=local-cluster&kind=placementrule&name=mortgage-rule"
+        },
+        label: "View Resource YAML"
+      }
+    },
     { type: "spacer" },
     { labelKey: "prop.details.section", type: "label" },
     { type: "spacer" },
@@ -1168,6 +1192,14 @@ describe("getNodeDetails placement rules node with success", () => {
       type: "label",
       value: "placements"
     },
+    {
+      indent: undefined,
+      labelKey: "resource.api.version",
+      labelValue: undefined,
+      status: undefined,
+      type: "label",
+      value: "apps.open-cluster-management.io/v1"
+    },
     {
       indent: undefined,
       labelKey: "resource.namespace",
@@ -1204,7 +1236,7 @@ describe("getNodeDetails placement rules node with success", () => {
   ];
 
   it("should process the node, placement rules node with success", () => {
-    expect(getNodeDetails(rulesNode, locale)).toEqual(expectedResult);
+    expect(getNodeDetails(rulesNode, locale, {})).toEqual(expectedResult);
   });
 });
 
